==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/ListBuildServiceBuilderDeploymentsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.ListBuildServiceBuilderDeploymentsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property buildServiceName The name of the build service resource.
 * @property builderName The name of the builder resource.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serviceName The name of the Service resource.
 */
public data class ListBuildServiceBuilderDeploymentsPlainArgs(
    public val buildServiceName: String,
    public val builderName: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.ListBuildServiceBuilderDeploymentsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.ListBuildServiceBuilderDeploymentsPlainArgs =
        com.pulumi.azurenative.appplatform.inputs.ListBuildServiceBuilderDeploymentsPlainArgs.builder()
            .buildServiceName(buildServiceName.let({ args0 -> args0 }))
            .builderName(builderName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListBuildServiceBuilderDeploymentsPlainArgs].
 */
@PulumiTagMarker
public class ListBuildServiceBuilderDeploymentsPlainArgsBuilder internal constructor() {
    private var buildServiceName: String? = null

    private var builderName: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value The name of the build service resource.
     */
    @JvmName("spnrtbprhhpvjtdh")
    public suspend fun buildServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.buildServiceName = mapped
    }

    /**
     * @param value The name of the builder resource.
     */
    @JvmName("rkfsojboosvacrwr")
    public suspend fun builderName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.builderName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("mhlfqahfgpefbeib")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("vlyopayxtoeoqskm")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): ListBuildServiceBuilderDeploymentsPlainArgs =
        ListBuildServiceBuilderDeploymentsPlainArgs(
            buildServiceName = buildServiceName ?: throw PulumiNullFieldException("buildServiceName"),
            builderName = builderName ?: throw PulumiNullFieldException("builderName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/ListBuildServiceBuilderDeploymentsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.ListBuildServiceBuilderDeploymentsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property buildServiceName The name of the build service resource.
 * @property builderName The name of the builder resource.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serviceName The name of the Service resource.
 */
public data class ListBuildServiceBuilderDeploymentsPlainArgs(
    public val buildServiceName: String,
    public val builderName: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.ListBuildServiceBuilderDeploymentsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.ListBuildServiceBuilderDeploymentsPlainArgs =
        com.pulumi.azurenative.appplatform.inputs.ListBuildServiceBuilderDeploymentsPlainArgs.builder()
            .buildServiceName(buildServiceName.let({ args0 -> args0 }))
            .builderName(builderName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListBuildServiceBuilderDeploymentsPlainArgs].
 */
@PulumiTagMarker
public class ListBuildServiceBuilderDeploymentsPlainArgsBuilder internal constructor() {
    private var buildServiceName: String? = null

    private var builderName: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value The name of the build service resource.
     */
    @JvmName("wledfhancdsvftxn")
    public suspend fun buildServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.buildServiceName = mapped
    }

    /**
     * @param value The name of the builder resource.
     */
    @JvmName("xukkcxkqojuwnvig")
    public suspend fun builderName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.builderName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("gvkxwiuocilttlwk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("wdadsldqjwdxgvdk")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): ListBuildServiceBuilderDeploymentsPlainArgs =
        ListBuildServiceBuilderDeploymentsPlainArgs(
            buildServiceName = buildServiceName ?: throw PulumiNullFieldException("buildServiceName"),
            builderName = builderName ?: throw PulumiNullFieldException("builderName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
        )
}
